@@ -9,6 +9,6 @@ import pyscreenshot as ImageGrab
 with Display(size=(100, 60)) as disp:  # start Xvfb display
     # display is available
     with EasyProcess(["xmessage", "hello"]):  # start xmessage
-        sleep(1)  # wait for diplaying window
+        sleep(1)  # wait for displaying window
         img = ImageGrab.grab()
 img.save("xmessage.png")
